<?php
$lang->workflowlabel->common   = '工作流標籤';
$lang->workflowlabel->browse   = '所有標籤';
$lang->workflowlabel->create   = '新增標籤';
$lang->workflowlabel->edit     = '編輯標籤';
$lang->workflowlabel->delete   = '刪除標籤';
$lang->workflowlabel->sort     = '標籤排序';
$lang->workflowlabel->search   = '搜索';
$lang->workflowlabel->settings = '標籤及屬性設置';

$lang->workflowlabel->id          = '編號';
$lang->workflowlabel->module      = '所屬模組';
$lang->workflowlabel->label       = '檢索標籤';
$lang->workflowlabel->params      = '檢索條件';
$lang->workflowlabel->order       = '順序';
$lang->workflowlabel->buildin     = '內置';
$lang->workflowlabel->createdBy   = '由誰創建';
$lang->workflowlabel->createdDate = '創建日期';
$lang->workflowlabel->editedBy    = '由誰編輯';
$lang->workflowlabel->editedDate  = '編輯日期';

$lang->workflowlabel->buildinList['0'] = '否';
$lang->workflowlabel->buildinList['1'] = '是';

$lang->workflowlabel->default = new stdclass();
$lang->workflowlabel->default->labels['all'] = '所有';

$lang->workflowlabel->error = new stdclass();
$lang->workflowlabel->error->emptyParams = '檢索條件不能為空！';

$lang->workflowlabel->placeholder = new stdclass();
$lang->workflowlabel->placeholder->known    = '知道了';
$lang->workflowlabel->placeholder->features = '在流程的列表頁可以通過這些標籤查看和瀏覽。';
